@@ -10,29 +10,38 @@ type_label <- function(object) {
 
 #' Default color palette
 #' 
-#' The default color palette for the graphics, imported from the package
-#' \pkg{scales}. The chosen palette function depends on the input object.
+#' The default color palette for the graphics, inspired from the package
+#' \pkg{scales} whose scales can also be used as alternatives.
 #' 
 #' @keywords internal
 #' @export
-#' @importFrom scales brewer_pal div_gradient_pal
+#' @importFrom grDevices colorRampPalette
+#' @importFrom RColorBrewer brewer.pal
 default_col_pal <- function(object) {
-  if (identical(attr(object,"type"),"contributions")) brewer_pal(type = "qual",palette = 7L)
-  else if (identical(attr(object,"func"),"in_scatter")) function(n) div_gradient_pal()(seq(0, 1, length.out = n))
-  else brewer_pal(type = "qual",palette = 6L)
+  if (identical(attr(object,"type"),"contributions")) function(n) suppressWarnings(brewer.pal(n,"Set2"))[seq_len(n)]
+  else if (identical(attr(object,"func"),"in_scatter")) colorRampPalette(colors = c("#2B6788","#CBCBCB","#90503F"),space = "Lab")
+  else function(n) suppressWarnings(brewer.pal(n,"Set1"))[seq_len(n)]
 }
 
-#' Default color palette
+#' Default linetype palette
 #' 
-#' The default palette for the graphics. `linetype_pal` is imported from the
-#' package \pkg{scales}.
+#' The default linetype palette for the graphics. The palette for the objects
+#' with another class than `"in_scatter"` is taken from `linetype_pal` as seen
+#' in the package \pkg{scales}. Hence it is based on a set supplied by Richard
+#' Pearson, University of Manchester.
 #' 
 #' @keywords internal
 #' @export
-#' @importFrom scales linetype_pal
 default_lty_pal <- function(object) {
   if (identical(attr(object,"func"),"in_scatter")) seq_len
-  else linetype_pal()
+  else {
+    types <- c("solid", "22", "42", "44", 
+               "13", "1343", "73", "2262", "12223242", 
+               "F282", "F4448444", "224282F2", "F1")
+    function(n) {
+      types[seq_len(n)]
+    }
+  }
 }
 
 #' Default margins
@@ -422,7 +431,11 @@ plot.threeRuleSmooth <- function(x, xlab = NULL, ylab = NULL,
 #' benchmark <- twoStepsBenchmark(turnover,construction,include.rho = TRUE)
 #' plot(benchmark)
 #' plot(in_sample(benchmark))
-#' autoplot(in_disaggr(benchmark,type="changes"),start=c(2015,1),end=c(2020,12))
+#' if(require("ggplot2")) {
+#'   autoplot(in_disaggr(benchmark,type="changes"),
+#'            start=c(2015,1),
+#'            end=c(2020,12))
+#' }
 #' plot(in_scatter(benchmark),xlab="title x",ylab="title y")
 #' @export
 plot.tscomparison <- function(x, xlab = NULL, ylab = NULL, start = NULL, end = NULL,
@@ -486,16 +499,19 @@ plot.tscomparison <- function(x, xlab = NULL, ylab = NULL, start = NULL, end = N
 #' @keywords internal
 #' @export
 default_theme_ggplot <- function(show.legend,xlab,ylab,mar) {
-  classic <- theme_classic()
-  classic %+replace%
-    theme(axis.title.x = if (is.null(xlab)) element_blank() else classic$axis.title.x,
-          axis.title.y = if (is.null(ylab)) element_blank() else classic$axis.title.y,
-          plot.margin =  if (is.null(mar)) classic$plot.margin else margin(mar[3L],mar[4L],
-                                                                           mar[1L],mar[2L],
-                                                                           unit="pt"),
-          panel.grid.major = element_line(colour = "#cccccc"),
-          legend.position = if (show.legend) "bottom" else "none"
+  classic <- ggplot2::theme_classic()
+  
+  ggplot2::`%+replace%`(
+    classic,
+    ggplot2::theme(axis.title.x = if (is.null(xlab)) ggplot2::element_blank() else classic$axis.title.x,
+                   axis.title.y = if (is.null(ylab)) ggplot2::element_blank() else classic$axis.title.y,
+                   plot.margin =  if (is.null(mar)) classic$plot.margin else ggplot2::margin(mar[3L],mar[4L],
+                                                                                             mar[1L],mar[2L],
+                                                                                             unit="pt"),
+                   panel.grid.major = ggplot2::element_line(colour = "#cccccc"),
+                   legend.position = if (show.legend) "bottom" else "none"
     )
+  )
 }
 
 gglims <- function(object) c(tsp(object)[1L],tsp(object)[2L] + deltat(object))
@@ -518,20 +534,20 @@ ggplotts.data.frame <- function(object,show.legend, theme,type,
   
   object <- object[!is.na(object$Values),]
   
-  group <- enquo(group)
+  group <- ggplot2::enquo(group)
   
-  g <- ggplot(object,aes(x=Date,y=Values),show.legend = show.legend,...) +
-    xlab(xlab) + ylab(ylab)
+  g <- ggplot2::ggplot(object,ggplot2::aes(x=Date,y=Values),show.legend = show.legend,...) +
+    ggplot2::xlab(xlab) + ggplot2::ylab(ylab)
   switch(type,
-         line = g + geom_line(aes(colour=Variables,linetype=Variables,group=!!group),
-                              na.rm = TRUE),
-         bar = g + geom_bar(aes(fill=Variables,group=!!group),stat="identity") +
-           stat_summary(fun = sum, geom="line", colour = "black",
-                        size = 0.5, alpha=1,na.rm = TRUE),
-         segment = g + geom_segment(aes(xend=Date,colour=Variables,group=!!group),
-                                    yend=0)
+         line = g + ggplot2::geom_line(ggplot2::aes(colour=Variables,linetype=Variables,group=!!group),
+                                       na.rm = TRUE),
+         bar = g + ggplot2::geom_bar(ggplot2::aes(fill=Variables,group=!!group),stat="identity") +
+           ggplot2::stat_summary(fun = sum, geom="line", colour = "black",
+                                 size = 0.5, alpha=1,na.rm = TRUE),
+         segment = g + ggplot2::geom_segment(ggplot2::aes(xend=Date,colour=Variables,group=!!group),
+                                             yend=0)
   ) +
-    scale_x_continuous(
+    ggplot2::scale_x_continuous(
       limits = lims,
       breaks = (floor(lims[1L]+verysmall)+1L):(ceiling(lims[2L]-verysmall)-1L),
       minor_breaks = numeric(),
@@ -569,16 +585,16 @@ geom_path_scatter <- function(object,i,lty) {
                    xend = object[-1L,2L],
                    yend = object[-1L,1L], check.names = FALSE)
   
-  geom_segment(data=df,
-               aes(x = `High-frequency serie`, y = `Low-frequency serie`,
-                   xend = xend, yend = yend,
-                   colour = Time, group = i),
-               linetype = lty,
-               arrow=arrow(angle = 15,
-                           ends = "last",
-                           type = "closed",
-                           length = unit(0.1,"inches")),
-               na.rm = TRUE)
+  ggplot2::geom_segment(data=df,
+                        ggplot2::aes(x = `High-frequency serie`, y = `Low-frequency serie`,
+                                     xend = xend, yend = yend,
+                                     colour = Time, group = i),
+                        linetype = lty,
+                        arrow=ggplot2::arrow(angle = 15,
+                                             ends = "last",
+                                             type = "closed",
+                                             length = ggplot2::unit(0.1,"inches")),
+                        na.rm = TRUE)
 }
 
 ggscatter <- function(object,show.legend, theme, start, end, xlab,ylab,
@@ -590,12 +606,12 @@ ggscatter <- function(object,show.legend, theme, start, end, xlab,ylab,
   
   lty <- lty(ncol(object)-1L)
   
-  g <- ggplot(show.legend = show.legend, ...) + xlab(xlab) + ylab(ylab)
+  g <- ggplot2::ggplot(show.legend = show.legend, ...) + ggplot2::xlab(xlab) + ggplot2::ylab(ylab)
   
   if (!is.null(attr(object,"abline"))) {
-    g <- g + geom_abline(intercept = attr(object,"abline")["constant"],
-                         slope = attr(object,"abline")["slope"],
-                         lty = "solid", colour = "red", size = 1)
+    g <- g + ggplot2::geom_abline(intercept = attr(object,"abline")["constant"],
+                                  slope = attr(object,"abline")["slope"],
+                                  lty = "solid", colour = "red", size = 1)
   }
   
   g <- g + geom_path_scatter(object[,c(1L,2L)],1L,lty[1L])
@@ -617,13 +633,13 @@ ggscatter <- function(object,show.legend, theme, start, end, xlab,ylab,
     
     # These are the parts before and after the coefficients calc window
   }
-  g <- g + continuous_scale("colour","gradient",function(x) col(length(x)),
-                            limits = lims,
-                            breaks = break_arrows(as.numeric(time(object)[-1])),
-                            minor_breaks = numeric(),
-                            expand=c(0,0)) +
+  g <- g + ggplot2::continuous_scale("colour","gradient",function(x) col(length(x)),
+                                     limits = lims,
+                                     breaks = break_arrows(as.numeric(time(object)[-1])),
+                                     minor_breaks = numeric(),
+                                     expand=c(0,0)) +
     theme +
-    guides(colour=guide_legend(override.aes = list(arrow = NULL)))
+    ggplot2::guides(colour=ggplot2::guide_legend(override.aes = list(arrow = NULL)))
   g
 }
 
@@ -634,9 +650,6 @@ function_if_it_isnt_one <- function(f) {
   }
 }
 
-#' @export
-ggplot2::autoplot
-
 autoplot_with_lf <- function(object, xlab, ylab,
                              start, end, col, lty,
                              show.legend, main,
@@ -664,12 +677,12 @@ autoplot_with_lf <- function(object, xlab, ylab,
            lims = gglims(hfbench),
            verysmall = getOption("ts.eps")/frequency(model$hfserie),
            ...) +
-    discrete_scale("colour","hue",col,na.translate = FALSE) +
-    discrete_scale("linetype","hue",lty,na.translate = FALSE) +
-    ggtitle(main)
+    ggplot2::discrete_scale("colour","hue",col,na.translate = FALSE) +
+    ggplot2::discrete_scale("linetype","hue",lty,na.translate = FALSE) +
+    ggplot2::ggtitle(main)
 }
 
-#' @export
+#' @exportS3Method ggplot2::autoplot
 #' @rdname plot.tscomparison
 autoplot.twoStepsBenchmark <- function(object, xlab = NULL, ylab = NULL,
                                        start=NULL,end=NULL,
@@ -689,7 +702,7 @@ autoplot.twoStepsBenchmark <- function(object, xlab = NULL, ylab = NULL,
                    ...)
 }
 
-#' @export
+#' @exportS3Method ggplot2::autoplot
 #' @rdname plot.tscomparison
 autoplot.threeRuleSmooth <- function(object, xlab = NULL, ylab = NULL,
                                      start=NULL,end=NULL,
@@ -709,7 +722,7 @@ autoplot.threeRuleSmooth <- function(object, xlab = NULL, ylab = NULL,
                    ...)
 }
 
-#' @export
+#' @exportS3Method ggplot2::autoplot
 #' @rdname plot.tscomparison
 autoplot.tscomparison <- function(object, xlab = NULL, ylab = NULL,
                                   start=NULL,end=NULL,
@@ -734,9 +747,9 @@ autoplot.tscomparison <- function(object, xlab = NULL, ylab = NULL,
              type = "bar", series_names = colnames(object), theme = theme,
              start = start, end = end,
              xlab = xlab, ylab = ylab, ...) +
-      labs(fill=type_label) +
-      discrete_scale("fill","hue",col,na.translate = FALSE) +
-      ggtitle(main)
+      ggplot2::labs(fill=type_label) +
+      ggplot2::discrete_scale("fill","hue",col,na.translate = FALSE) +
+      ggplot2::ggtitle(main)
   }
   else switch(attr(object,"func"),
               in_revisions = {
@@ -744,25 +757,25 @@ autoplot.tscomparison <- function(object, xlab = NULL, ylab = NULL,
                          type="segment", series_names = colnames(object),theme = theme,
                          start = start, end = end,
                          xlab = xlab, ylab = ylab, ...) +
-                  labs(colour=type_label) +
-                  discrete_scale("colour","hue",col,na.translate = FALSE) +
-                  ggtitle(main)
+                  ggplot2::labs(colour=type_label) +
+                  ggplot2::discrete_scale("colour","hue",col,na.translate = FALSE) +
+                  ggplot2::ggtitle(main)
               },
               in_scatter = {
                 ggscatter(object = object, show.legend = show.legend,
                           theme = theme, start = start, end = end,
                           xlab = xlab, ylab = ylab,
                           col = col, lty = lty,...) +
-                  ggtitle(main)
+                  ggplot2::ggtitle(main)
               },
               ggplotts(object = object, show.legend = show.legend,
                        type="line",series_names = colnames(object), theme = theme,
                        start = start, end = end,
                        xlab = xlab, ylab = ylab, ...) +
-                labs(linetype=type_label) +
-                labs(colour=type_label) +
-                discrete_scale("colour","hue",col,na.translate = FALSE) +
-                discrete_scale("linetype", "linetype_d", lty,na.translate = FALSE) +
-                ggtitle(main)
+                ggplot2::labs(linetype=type_label) +
+                ggplot2::labs(colour=type_label) +
+                ggplot2::discrete_scale("colour","hue",col,na.translate = FALSE) +
+                ggplot2::discrete_scale("linetype", "linetype_d", lty,na.translate = FALSE) +
+                ggplot2::ggtitle(main)
   )
 }
