@@ -8,13 +8,7 @@ test_that("function_if_it_isnt_one works", {
                    lapply(1:20,function(n) rep("Hey",n)))
 })
 
-expect_doppelganger <- function (title, fig) {
-  withCallingHandlers({
-    vdiffr::expect_doppelganger(title, fig)
-  }, warning = function(w) if (inherits(w,"warning") &&
-                               grepl("expect_snapshot_file",w$message))
-    tryInvokeRestart("muffleWarning"))
-}
+expect_doppelganger <- vdiffr::expect_doppelganger
 
 test_that("plot works with twoStepsBenchmark", {
   skip_if_not_installed("vdiffr")
@@ -172,6 +166,7 @@ test_that("plot works with twoStepsBenchmark", {
 
 test_that("ggplot works", {
   skip_if_not_installed("vdiffr")
+  testthat::skip_if_not_installed("ggplot2")
   skip_on_cran()
   benchmark <- twoStepsBenchmark(hfserie = turnover,
                                  lfserie = construction,
@@ -181,132 +176,121 @@ test_that("ggplot works", {
                                   include.differenciation = FALSE,
                                   set.const = TRUE)
   
-  expect_doppelganger("gg-benchmark-nowin",autoplot(benchmark))
+  expect_doppelganger("gg-benchmark-nowin",ggplot2::autoplot(benchmark))
   
   expect_doppelganger("gg-insample-levels-nowin",
-                      autoplot(in_sample(benchmark,type="levels")))
+                      ggplot2::autoplot(in_sample(benchmark,type="levels")))
   expect_doppelganger("gg-insample-changes-nowin",
-                      autoplot(in_sample(benchmark,type="changes")))
+                      ggplot2::autoplot(in_sample(benchmark,type="changes")))
   
   expect_doppelganger("gg-indicator-levels-nowin",
-                      autoplot(in_disaggr(benchmark,type="levels")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels")))
   expect_doppelganger("gg-indicator-levels-rebased-nowin",
-                      autoplot(in_disaggr(benchmark,type="levels-rebased")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels-rebased")))
   expect_doppelganger("gg-indicator-changes-nowin",
-                      autoplot(in_disaggr(benchmark,type="changes")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="changes")))
   expect_doppelganger("gg-indicator-contributions-nowin",
-                      autoplot(in_disaggr(benchmark,type="contributions")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="contributions")))
   
   expect_doppelganger("gg-inrevisions-levels-nowin",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="levels")))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="levels")))
   expect_doppelganger("gg-inrevisions-levels-rebased-nowin",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="levels-rebased")))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="levels-rebased")))
   expect_doppelganger("gg-inrevisions-changes-nowin",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="changes")))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="changes")))
   expect_doppelganger("gg-inrevisions-contributions-nowin",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="contributions")))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="contributions")))
   
   expect_doppelganger("gg-benchmark-2008-4-2012-7",
-                      autoplot(benchmark,
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(benchmark,
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   
   expect_doppelganger("gg-insample-levels-2008-2012",
-                      autoplot(in_sample(benchmark,type="levels"),
-                               start=2008,
-                               end=2012))
+                      ggplot2::autoplot(in_sample(benchmark,type="levels"),
+                                        start=2008,
+                                        end=2012))
   expect_doppelganger("gg-insample-changes-2008-2012",
-                      autoplot(in_sample(benchmark,type="changes"),
-                               start=2008,
-                               end=2012))
+                      ggplot2::autoplot(in_sample(benchmark,type="changes"),
+                                        start=2008,
+                                        end=2012))
   
   expect_doppelganger("gg-indicator-levels-2008-4-2012-7",
-                      autoplot(in_disaggr(benchmark,type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-levels-rebased-2008-4-2012-7",
-                      autoplot(in_disaggr(benchmark,type="levels-rebased"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels-rebased"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-changes-2008-4-2012-7",
-                      autoplot(in_disaggr(benchmark,type="changes"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="changes"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-contributions-2008-4-2012-7",
-                      autoplot(in_disaggr(benchmark,type="contributions"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="contributions"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   
   expect_doppelganger("gg-inrevisions-levels-2008-4-2012-7",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-levels-rebased-2008-4-2012-7",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-changes-2008-4-2012-7",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="changes"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="changes"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-contributions-2008-4-2012-7",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="contributions"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
-  
-  announce_snapshot_file(name = "gg-plot-scatter-2008-2012.svg")
-  if (packageVersion("ggplot2") != "3.3.4") {
-    expect_doppelganger("gg-plot-scatter-2008-2012",
-                        autoplot(in_scatter(benchmark),
-                                 start=2008,
-                                 end=2012))
-  }
-  
-  announce_snapshot_file(name = "gg-plot-scatter-coeff-2008-2012.svg")
-  if (packageVersion("ggplot2") != "3.3.4") {
-    expect_doppelganger("gg-plot-scatter-coeff-2008-2012",
-                        autoplot(in_scatter(twoStepsBenchmark(turnover,
-                                                              construction,
-                                                              start.coeff.calc = 2008,
-                                                              end.coeff.calc = 2012))))
-  }
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="contributions"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
+  expect_doppelganger("gg-plot-scatter-2008-2012",
+                      ggplot2::autoplot(in_scatter(benchmark),
+                                        start=2008,
+                                        end=2012))
+  expect_doppelganger("gg-plot-scatter-coeff-2008-2012",
+                      ggplot2::autoplot(in_scatter(twoStepsBenchmark(turnover,
+                                                                     construction,
+                                                                     start.coeff.calc = 2008,
+                                                                     end.coeff.calc = 2012))))
   
   expect_doppelganger("gg-main-insample",
-                      autoplot(in_sample(benchmark),
-                               main="title in sample"))
+                      ggplot2::autoplot(in_sample(benchmark),
+                                        main="title in sample"))
   expect_doppelganger("gg-plot-main-inrev",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2),
-                               main="title in rev"))
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2),
+                                        main="title in rev"))
   expect_doppelganger("gg-plot-main-ctb",
-                      autoplot(in_disaggr(benchmark,
-                                          type = "contributions"),
-                               main="title ctb"))
-  announce_snapshot_file(name = "gg-plot-main-scatter.svg")
-  if (packageVersion("ggplot2") != "3.3.4") {
+                      ggplot2::autoplot(in_disaggr(benchmark,
+                                                   type = "contributions"),
+                                        main="title ctb"))
   expect_doppelganger("gg-plot-main-scatter",
-                      autoplot(in_scatter(benchmark),
-                               main="title scatter"))
-  }
+                      ggplot2::autoplot(in_scatter(benchmark),
+                                        main="title scatter"))
 })
 
-test_that("show.legend=FALSE works", {
+test_that("show.legend=FALSE works with plot", {
   skip_if_not_installed("vdiffr")
   skip_on_cran()
   benchmark <- twoStepsBenchmark(hfserie = turnover,
@@ -334,35 +318,49 @@ test_that("show.legend=FALSE works", {
                                                    benchmark2,
                                                    type="changes"),
                                       show.legend = FALSE))
-  
-  announce_snapshot_file(name = "plot-scatter-showlegendf.svg")
-  if (packageVersion("ggplot2") != "3.3.4") {
   expect_doppelganger("plot-scatter-showlegendF",
                       function() plot(in_scatter(benchmark),
                                       show.legend = FALSE))
-  }
+})
+
+test_that("show.legend=FALSE works with ggplot", {
+  skip_if_not_installed("vdiffr")
+  testthat::skip_if_not_installed("ggplot2")
+  skip_on_cran()
+  benchmark <- twoStepsBenchmark(hfserie = turnover,
+                                 lfserie = construction,
+                                 include.differenciation = TRUE)
+  
+  benchmark2 <- twoStepsBenchmark(hfserie = turnover,
+                                  lfserie = construction,
+                                  include.differenciation = FALSE,
+                                  set.const = TRUE)
   
   expect_doppelganger("gg-benchmark-showlegendF",
-                      autoplot(benchmark,show.legend = FALSE))
+                      ggplot2::autoplot(benchmark,show.legend = FALSE))
   expect_doppelganger("gg-insample-showlegendF",
-                      autoplot(in_sample(benchmark,type="levels"),
-                               show.legend = FALSE))
+                      ggplot2::autoplot(in_sample(benchmark,type="levels"),
+                                        show.legend = FALSE))
   expect_doppelganger("gg-indicator-showlegendF",
-                      autoplot(in_disaggr(benchmark,type="levels-rebased"),
-                               show.legend = FALSE))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels-rebased"),
+                                        show.legend = FALSE))
   expect_doppelganger("gg-ctb-showlegendF",
-                      autoplot(in_disaggr(benchmark,type="contributions"),
-                               show.legend = FALSE))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="contributions"),
+                                        show.legend = FALSE))
   expect_doppelganger("gg-inrevisions-showlegendF",
-                      autoplot(in_revisions(benchmark,
-                                            benchmark2,
-                                            type="changes"),
-                               show.legend = FALSE))
-  announce_snapshot_file("gg-scatter-showlegendf.svg")
-  # expect_doppelganger("gg-scatter-showlegendF",
-  #                     autoplot(in_scatter(benchmark),
-  #                              show.legend = FALSE))
-  
+                      ggplot2::autoplot(in_revisions(benchmark,
+                                                     benchmark2,
+                                                     type="changes"),
+                                        show.legend = FALSE))
+  expect_doppelganger("gg-scatter-showlegendF",
+                      ggplot2::autoplot(in_scatter(benchmark),
+                                        show.legend = FALSE))
+})
+
+test_that("mts ggplot", {
+  skip_if_not_installed("vdiffr")
+  testthat::skip_if_not_installed("ggplot2")
+  skip_on_cran()
   set.seed(1)
   series <- 10+replicate(3,arima.sim(list(order = c(1,1,0), ar = 0.8), n = 300))
   mts <- ts(series,start=c(2000,1),freq=12) %>%
@@ -370,22 +368,22 @@ test_that("show.legend=FALSE works", {
     twoStepsBenchmark(construction)
   
   expect_doppelganger("gg-mts-ctb",
-                      autoplot(in_disaggr(mts,
-                                          type = "contributions")))
+                      ggplot2::autoplot(in_disaggr(mts,
+                                                   type = "contributions")))
   expect_doppelganger("gg-mts-ins",
-                      autoplot(in_sample(mts,type="levels")))
+                      ggplot2::autoplot(in_sample(mts,type="levels")))
   
   expect_doppelganger("gg-mts-indic",
-                      autoplot(in_disaggr(mts,
-                                          type="levels-rebased")))
+                      ggplot2::autoplot(in_disaggr(mts,
+                                                   type="levels-rebased")))
   series <- 10+replicate(3,arima.sim(list(order = c(1,1,0), ar = 0.8), n = 300))
   mts2 <- ts(series,start=c(2000,1),freq=12) %>%
     `colnames<-`(c("a","b","c")) %>%
     twoStepsBenchmark(construction)
   expect_doppelganger("gg-mts-rev",
-                      autoplot(suppressWarnings(in_revisions(mts,
-                                                             mts2,
-                                                             type="levels"))))
+                      ggplot2::autoplot(suppressWarnings(in_revisions(mts,
+                                                                      mts2,
+                                                                      type="levels"))))
 })
 
 test_that("xlab and ylab works", {
@@ -401,11 +399,11 @@ test_that("xlab and ylab works", {
   expect_doppelganger("plot-benchmark-lab-bar",
                       function() plot(benchmark,ylab = "bar"))
   expect_doppelganger("gg-benchmark-lab-foo-bar",
-                      autoplot(benchmark,xlab = "foo",ylab="bar"))
+                      ggplot2::autoplot(benchmark,xlab = "foo",ylab="bar"))
   expect_doppelganger("gg-benchmark-lab-foo",
-                      autoplot(benchmark,xlab = "foo"))
+                      ggplot2::autoplot(benchmark,xlab = "foo"))
   expect_doppelganger("gg-benchmark-lab-bar",
-                      autoplot(benchmark,ylab="bar"))
+                      ggplot2::autoplot(benchmark,ylab="bar"))
 })
 
 test_that("plot works with threeRuleSmooth", {
@@ -515,6 +513,7 @@ test_that("plot works with threeRuleSmooth", {
 test_that("ggplot works with threeRuleSmooth", {
   skip_if_not_installed("vdiffr")
   skip_on_cran()
+  testthat::skip_if_not_installed("ggplot2")
   smooth <- threeRuleSmooth(hfserie = turnover,
                             lfserie = construction,
                             end.domain = c(2021,12))
@@ -524,96 +523,96 @@ test_that("ggplot works with threeRuleSmooth", {
                              end.domain = c(2021,12))
   
   expect_doppelganger("gg-nowin-smooth",
-                      autoplot(smooth))
+                      ggplot2::autoplot(smooth))
   
   expect_doppelganger("gg-indicator-levels-nowin-smooth",
-                      autoplot(in_disaggr(smooth,type="levels")))
+                      ggplot2::autoplot(in_disaggr(smooth,type="levels")))
   expect_doppelganger("gg-indicator-levels-rebased-nowin-smooth",
-                      autoplot(in_disaggr(smooth,type="levels-rebased")))
+                      ggplot2::autoplot(in_disaggr(smooth,type="levels-rebased")))
   expect_doppelganger("gg-indicator-changes-nowin-smooth",
-                      autoplot(in_disaggr(smooth,type="changes")))
+                      ggplot2::autoplot(in_disaggr(smooth,type="changes")))
   expect_doppelganger("gg-indicator-contributions-nowin-smooth",
-                      autoplot(in_disaggr(smooth,type="contributions")))
+                      ggplot2::autoplot(in_disaggr(smooth,type="contributions")))
   
   expect_doppelganger("gg-inrevisions-levels-nowin-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="levels")))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="levels")))
   expect_doppelganger("gg-inrevisions-levels-rebased-nowin-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="levels-rebased")))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="levels-rebased")))
   expect_doppelganger("gg-inrevisions-changes-nowin-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="changes")))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="changes")))
   expect_doppelganger("gg-inrevisions-contributions-nowin-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="contributions")))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="contributions")))
   
   expect_doppelganger("gg-smooth-2008-4-2012-7-smooth",
-                      autoplot(smooth,
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(smooth,
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   
   expect_doppelganger("gg-indicator-levels-2008-4-2012-7-smooth",
-                      autoplot(in_disaggr(smooth,type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(smooth,type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-levels-rebased-2008-4-2012-7-smooth",
-                      autoplot(in_disaggr(smooth,type="levels-rebased"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(smooth,type="levels-rebased"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-changes-2008-4-2012-7-smooth",
-                      autoplot(in_disaggr(smooth,type="changes"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(smooth,type="changes"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-indicator-contributions-2008-4-2012-7-smooth",
-                      autoplot(in_disaggr(smooth,type="contributions"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_disaggr(smooth,type="contributions"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   
   expect_doppelganger("gg-inrevisions-levels-2008-4-2012-7-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-levels-rebased-2008-4-2012-7-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="levels"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="levels"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-changes-2008-4-2012-7-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="changes"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="changes"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-inrevisions-contributions-2008-4-2012-7-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2,
-                                            type="contributions"),
-                               start=c(2008,4),
-                               end=c(2012,7)))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2,
+                                                     type="contributions"),
+                                        start=c(2008,4),
+                                        end=c(2012,7)))
   expect_doppelganger("gg-scatter-2008-2012-smooth",
-                      autoplot(in_scatter(smooth),
-                               start=2008,
-                               end=2012))
+                      ggplot2::autoplot(in_scatter(smooth),
+                                        start=2008,
+                                        end=2012))
   
   expect_doppelganger("gg-main-inrev-smooth",
-                      autoplot(in_revisions(smooth,
-                                            smooth2),
-                               main="title in rev"))
+                      ggplot2::autoplot(in_revisions(smooth,
+                                                     smooth2),
+                                        main="title in rev"))
   expect_doppelganger("gg-main-ctb-smooth",
-                      autoplot(in_disaggr(smooth,
-                                          type = "contributions"),
-                               main="title ctb"))
+                      ggplot2::autoplot(in_disaggr(smooth,
+                                                   type = "contributions"),
+                                        main="title ctb"))
   expect_doppelganger("gg-main-scatter-smooth",
-                      autoplot(in_scatter(smooth),
-                               main="title scatter"))
+                      ggplot2::autoplot(in_scatter(smooth),
+                                        main="title scatter"))
 })
 
 test_that("plot outliers in_disaggr",{
@@ -635,17 +634,18 @@ test_that("plot outliers in_disaggr",{
 test_that("ggplot outliers in_disaggr",{
   skip_if_not_installed("vdiffr")
   skip_on_cran()
+  testthat::skip_if_not_installed("ggplot2")
   benchmark <- twoStepsBenchmark(turnover,construction,
                                  outliers=list(LS2005=rep(0.1,12L)))
   
   expect_doppelganger("ggplot-indicator-levels-outlier",
-                      autoplot(in_disaggr(benchmark,type="levels")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels")))
   expect_doppelganger("ggplot-indicator-levels-rebased-outlier",
-                      autoplot(in_disaggr(benchmark,type="levels-rebased")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="levels-rebased")))
   expect_doppelganger("ggplot-indicator-changes-outlier",
-                      autoplot(in_disaggr(benchmark,type="changes")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="changes")))
   expect_doppelganger("ggplot-indicator-contributions-outlier",
-                      autoplot(in_disaggr(benchmark,type="contributions")))
+                      ggplot2::autoplot(in_disaggr(benchmark,type="contributions")))
 })
 
 test_that("eval_function_if_it_is_one works", {
